
# Under Construction 
This package is in the early development stage and not yet complete. Use it at your own risk.

# What is it?
CoziePy is a Python package to retrieve, process, and visualize data collected witht the [Cozie Apple app](https://cozie-apple.app/). It aims to make the handling aof Cozie data easier.

# Where to get it?
The package is availabe at the [Python Package Index (PyPI)](https://pypi.org/project/coziepy/).

```sh
pip install coziepy
```

# How to use it?
Import the package in any python script or notebook using the following line

```python
from coziepy import Cozie, CoziePlot
```

# License
[GPLv3](https://github.com/cozie-app/cozie-wizard/blob/main/LICENSE)

# Getting Help
For any kind of questions or feedback, the best place to go to is [GitHub Discussions](https://github.com/cozie-app/cozie-wizard/discussions/).